# The Methodology
The P.A.R.A system is surprisingly simple at first glance but very powerful when applied. At its core, it's just a four folder wide hierarchy with four-layer deeps, starting with those four root folders:

1.  Projects
2.  Areas
3.  Resources
4.  Archive

From there, each of the roots is allowed one sub-folder level and then notes. That's how the four levels deep work: App (1) -> `1. Projects` (2) -> P.A.R.A. Demo Vault (3) -> Methodology (4). The reason for this is to keep it manageable and easy to remember and navigate. That restriction was initially because of Evernote limitation, but it turns out to have some serendipity potential. By putting all your notes from similar "zone" and actionability together, you end up with many serendipitous findings of new related notes and ideas.

Just those root folders and their children, the system can contain everything most people needs for their notes and files. This taxonomy works because you don't split things based on categories but actionability and areas of your life. So now, let's define those roots to help see how it works.

## Definition
1.  Projects: *Every current project that is actionable with its notes, files, artifacts*
	- If you have a project that requires notes or files, it should have a folder in 1. Projects.
	- Since this folder is for projects you are working on _right now_, it's the most actionable and probably where you will spend most of your time.
2. Areas: *Zone of responsibility with standard to uphold over long periods*, parent, animals, management, coding, house.
	- Areas are **the personal** bucket of your life for important things that don't have an end date. You won't ever "stop" working on your health; for example, it's a constant ongoing thing.
	- While areas can (and often do) generate projects, they are not linked since it's already intuitive which areas a project comes from, so there's no need to create an explicit link between, for example, the "Server maintenance" project and the "Sysadmin" area.
	- Finally, because they are personal, areas contain information you wrote for _yourself only_ about those areas in your life. Which is opposite to 3. Resources.
3. Resources: *Zone of interest for various topics that don't require standard/responsibility*, game, cooking, productivity, technology.
	- Resources are **generally helpful for others**, not just you. For example, if someone was to ask you for information about cooking, you could zip that folder and send it to them.
	- The folders in there will very often reflect your various interests, what you're curious about and want to learn more about.
	- They are not necessarily actual "resources" as in PDF, Pictures, etc. they can also be notes about those subjects
4. Archives: *Where stuff from all the other category become unused*, finished project, change of responsibility, etc.
	- This folder will be where you put things you won't need for a while, as the name suggests. For the most part, something in there won't be seen for a time, and that's why it has the lowest actionability, but sometimes a new project could use things in there, or a change of areas might mean you need to get stuff out of there.
	- For example, you have lots of notes on living with a pet in a small apartment, and then you move to a new bigger one. You could move all those to the archive if one day you have to go back to a small apartment again take them out.

## Setup
The setup for it is pretty simple, create root folders for each category, like in this sandbox. From there, move all of your current notes into `4. Archives` as is with the same existing hierarchy (remember it's not deleted 😉). Then create one folder for each of your current projects you're working on in `1. Projects` (remember only one sub-folder to stay four levels deep). For `2. Areas`, if you already know some of them, you can create the folders already, but try not to have too many empty folders. Finally, `3. Resources`, you want to stay empty for now unless you already captured things that could go in it. The idea is that each time you go into `4. Archives` to take one of the "old" notes or files, you then move it to the right spot in the new taxonomy. Doing it this way will highlight the most used notes, and what's left behind can stay in Archive until it's finally used (or not).

Once you have the folder hierarchy done, you want to copy it across all your other systems; that is where P.A.R.A. starts to shine. You want to have the same hierarchy for your local files on your computer, in your notes, in your Dropbox/Google Drive/iCloud, and everywhere else you have to keep information. Doing that will make it very quick and easy to find things you might need for work or something in the same zone across all your apps. For this reason, the more system you integrate the taxonomy into, the easier finding things will be.

### Setup tips:
- If a note (or a file) can go into two different folders, you put it in the folder where you will **_most likely need it next_** since folders are based on actionability, and it will get moved anyway in the flow of things.
- You can also have the "same" folder in 2 different roots. For example, `2. Areas/Health` and `3. Resources/Health` the first one is **_your_** health notes and the other **general** health-related notes.
- Remember, you do **_not_** want to sort all your current notes and files and put them in the new folder, put them all in the Archive as is, and then move them out as you use them.
- You do **_not_** have to do every single folder for your local files and cloud service; create the sub-folders are you need them, **_but_** you need to have one complete setup, most likely in your notes, to act as the primary reference for the others.


# Next stop [[Workflows]]